package Bundle::POE::IRC;

use strict;
use vars qw($VERSION);

$VERSION = '1.01';

1;

__END__

=head1 NAME

Bundle::POE::IRC - Bundle to install all POE related IRC modules.

=head1 SYNOPSIS

    perl -MCPANPLUS -e 'install Bundle::POE::IRC'

=head1 DESCRIPTION

Bundle::POE::IRC - Bundle to install all POE related IRC modules and optional dependencies.

=head1 CONTENTS

POE 0.9917

POE::Component::Client::DNS 1.00

POE::Component::IRC 5.22

POE::Component::Server::IRC 1.11

=head1 AUTHOR

Chris Williams <chris@bingosnet.co.uk>

=cut
